
High-Level Reference
====================

The "high-level interface" (as distinct from the large, C-like API that talks
directly to HDF5) is how most users will interact with h5py.  It consists of
a small number of classes which represent the main HDF5 abstractions like
file, groups, and datasets.

.. toctree::

    file
    group
    dataset
    attr
    dims
